import click
import os
from .app import app
from .server import StandaloneServer


@click.command()
@click.option(
    '--port',
    default=8000,
    help='Port to listen on, default is 8000'
)
@click.option(
    '--upload-dir',
    default=os.getcwd(),
    help='Directory where uploads are stored, if not specified the current working directory will be used'
)
@click.option(
    '--baseurl',
    default=None,
    help='Base URL, e.g. http://example.com/'
)
def main(port, upload_dir, baseurl):
    if baseurl is None:
        baseurl = 'http://{host}:{port}/'.format(host='localhost', port=port)
        click.echo(
            click.style('You did not specify a Base URL, using default: ' + baseurl, fg='yellow')
        )

    app.config['UPLOAD_DIR'] = upload_dir
    app.config['BASE_URL'] = baseurl

    server_options = {
        'bind': '{ip}:{port}'.format(
            ip='0.0.0.0',
            port=port
        ),
        'workers': 4,
    }
    StandaloneServer(app, server_options).run()


if __name__ == '__main__':
    main()


from flask import Flask, abort, request, send_file
from werkzeug.utils import secure_filename
from uuid import uuid4
import os


app = Flask(__name__)


@app.route('/')
def index():
    return '<a href="https://github.com/kennell/curldrop">curldrop</a> is up and running'


@app.route('/<file>', methods=['PUT'])
def upload(file):
    uuid = uuid4().hex[:8]
    filename = uuid + "-" + secure_filename(file)
    savepath = os.path.join(app.config['UPLOAD_DIR'], filename)
    with open(savepath, 'wb') as f:
        f.write(request.data)
    return app.config['BASE_URL'] + uuid


@app.route('/<uuid>', methods=['GET'])
def download(uuid):
    for file in os.listdir(app.config['UPLOAD_DIR']):
        if file.startswith(uuid):
            return send_file(
                os.path.join(os.getcwd(), app.config['UPLOAD_DIR'], file),
                as_attachment=True,
                attachment_filename=file.split('-', 1)[1]
            )
    return abort(404)



from setuptools import setup, find_packages

setup(
    name = "curldrop",
    version = "1.0.1",
    packages = find_packages(),
    author = "Kevin Kennell",
    author_email = "kevin@kennell.de",
    license = "MIT",
    url = "http://github.com/kennell/curldrop",
    install_requires=[
        'flask',
        'click',
        'gunicorn'
    ],
    entry_points={
        'console_scripts': [
            'curldrop = curldrop.cli:main'
        ]
    }
)
